@@ -3,12 +3,8 @@ Grok allows you to set up catalog indexes in your application with a
 special indexes declaration. In fact, these indexes can be set up for
 any site::
 
-  >>> import grok
-  >>> grok.grok('grok.ftests.catalog.indexes_site')
-
 Let's set up a site in which we manage a couple of objects::
 
-  >>> from grok.ftests.catalog.indexes_site import Herd
   >>> herd = Herd()
   >>> getRootFolder()['herd'] = herd
   >>> from zope.app.component.hooks import setSite
