@@ -2,7 +2,7 @@
 If the model is defined after the adapter, it should still be grokked
 properly:
 
-  >>> grok.grok(__name__)
+  >>> grok.testing.grok(__name__)
 
   >>> cave = Cave()
   >>> home = IHome(cave)
