@@ -2,24 +2,27 @@
 Since grok.global_utility is a MultipleTimesDirective, there is a list of
 GlobalUtilityInfo objects annotated on the module.
 
-  >>> from martian import scan
   >>> from grok.tests.directive import multipletimes
-  >>> module_info = scan.module_info_from_module(multipletimes)
-  >>> guis = module_info.getAnnotation('grok.global_utility', None)
-  >>> guis
-  [<grok.directive.GlobalUtilityInfo object at 0x...>,
-  <grok.directive.GlobalUtilityInfo object at 0x...>]
-  >>> guis[0].factory
+  >>> guis = grok.global_utility.bind().get(module=multipletimes)
+
+  >>> guis = grok.global_utility.bind().get(module=multipletimes)
+  >>> len(guis)
+  2
+
+  >>> factory, provides, name, direct = guis[0]
+  >>> factory
   <class 'grok.tests.directive.multipletimes.Club'>
-  >>> guis[0].provides
+  >>> provides
   <InterfaceClass grok.tests.directive.multipletimes.IClub>
-  >>> guis[0].name
+  >>> name
   'foo'
-  >>> guis[1].factory
+
+  >>> factory, provides, name, direct = guis[1]
+  >>> factory
   <class 'grok.tests.directive.multipletimes.Cave'>
-  >>> guis[1].provides is None
+  >>> provides is None
   True
-  >>> guis[1].name
+  >>> name
   u''
   
 """
