@@ -5,26 +5,11 @@ interface, there is no need to specify which interface it provides.
 In this test, the utility implements more than one interface, so it cannot be
 registered as a local utility.
 
-  >>> grok.grok(__name__)
+  >>> import grok.tests.utility.local_implementsmany_fixture
   Traceback (most recent call last):
     ...
-  GrokError: <class 'grok.tests.utility.local_implementsmany.Fireplace'>
+  GrokError: <class 'grok.tests.utility.local_implementsmany_fixture.Fireplace'>
   is implementing more than one interface (use grok.provides to specify
   which one to use).
 
 """
-
-import grok
-from zope import interface
-
-class IHome(interface.Interface):
-    pass
-
-class IFireplace(interface.Interface):
-    pass
-
-class Fireplace(object):
-    interface.implements(IHome, IFireplace)
-
-class Cave(grok.Model, grok.Site):
-    grok.local_utility(Fireplace)
