@@ -5,19 +5,10 @@ interface, there is no need to specify which interface it provides.
 In this test, the utility does not implement any interface, so it cannot be
 registered as a local utility.
 
-  >>> grok.grok(__name__)
+  >>> import grok.tests.utility.local_implementsnone_fixture
   Traceback (most recent call last):
     ...
-  GrokError: <class 'grok.tests.utility.local_implementsnone.Fireplace'>
+  GrokError: <class 'grok.tests.utility.local_implementsnone_fixture.Fireplace'>
   must implement at least one interface (use grok.implements to specify).
 
 """
-
-import grok
-from zope import interface
-
-class Fireplace(object):
-    pass
-
-class Cave(grok.Model, grok.Site):
-    grok.local_utility(Fireplace)
